#!/usr/bin/env python3

import os
import pathlib
import shutil
import sys

CMD = (
    "ffmpeg -loglevel error -i '{inputfile}' "
    "-vn -ab 128k -ar 44100 "
    "'{outputile}'"
)

for tmp_path in ["/massive/tmp/", "/home/facundo/temp/"]:
    if os.path.exists(tmp_path):
        break
else:
    print("ERROR: temp backup path not found")
    exit()


def main(inp_fpath):
    out_fpath = inp_fpath.with_suffix(".mp3")

    if out_fpath == inp_fpath:
        # rename input so don't collide
        alt_inp_fpath = inp_fpath.with_suffix(".original.mp3")
        inp_fpath.rename(alt_inp_fpath)
        inp_fpath = alt_inp_fpath

    # assure env is ok
    print("Processing", inp_fpath)
    assert inp_fpath.exists()
    assert not os.path.exists(out_fpath)

    cmd = CMD.format(inputfile=inp_fpath, outputile=out_fpath)
    status = os.system(cmd)
    if status != 0:
        print("ERROR, status:", status)
        exit()

    # move the old one to /tmp, to take it from the working dir (but don't just remove it, JIC)
    shutil.move(inp_fpath, f"{tmp_path}{inp_fpath}.backup")


if __name__ == '__main__':
    def die():
        print("Usage: {} input [input [...]]".format(sys.argv[0]))
        exit()

    if len(sys.argv) < 2:
        die()

    for fname in sys.argv[1:]:
        main(pathlib.Path(fname))
